@@ -28,6 +28,7 @@ import org.apache.pdfbox.pdmodel.PDDocument;
 import org.apache.pdfbox.pdmodel.PDDocumentCatalog;
 import org.apache.pdfbox.pdmodel.PDDocumentNameDictionary;
 import org.apache.pdfbox.pdmodel.PDEmbeddedFilesNameTreeNode;
+import org.apache.pdfbox.pdmodel.common.COSObjectable;
 import org.apache.pdfbox.pdmodel.common.filespecification.PDComplexFileSpecification;
 import org.apache.pdfbox.pdmodel.common.filespecification.PDEmbeddedFile;
 import org.apache.pdfbox.pdmodel.encryption.AccessPermission;
@@ -281,9 +282,9 @@ public class ExtractText
                     PDEmbeddedFilesNameTreeNode embeddedFiles = names.getEmbeddedFiles();
                     if (embeddedFiles != null)
                     {
-                        Map<String,Object> embeddedFileNames = embeddedFiles.getNames();
+                        Map<String,COSObjectable> embeddedFileNames = embeddedFiles.getNames();
                         if (embeddedFileNames != null) {
-                            for (Map.Entry<String,Object> ent : embeddedFileNames.entrySet()) 
+                            for (Map.Entry<String,COSObjectable> ent : embeddedFileNames.entrySet()) 
                             {
                                 if (debug)
                                 {
