@@ -25,12 +25,11 @@ import java.util.concurrent.ConcurrentHashMap;
 import org.apache.pdfbox.exceptions.COSVisitorException;
 import org.apache.pdfbox.persistence.util.COSHEXTable;
 
-
 /**
  * This class represents a PDF named object.
  *
  * @author <a href="mailto:ben@benlitchfield.com">Ben Litchfield</a>
- * @version $Revision: 1.42 $
+ * 
  */
 public final class COSName extends COSBase implements Comparable<COSName>
 {
@@ -382,6 +381,10 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName DECODE_PARMS = new COSName( "DecodeParms" );
 
+    /**
+     * A common COSName value.
+     */
+    public static final COSName DESC = new COSName("Desc");
     /**
      * A common COSName value.
      */
@@ -400,6 +403,11 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName DESTS = new COSName( "Dests" );
 
+    /**
+     * A common COSName value.
+     */
+    public static final COSName DEST_OUTPUT_PROFILE = new COSName("DestOutputProfile");
+
     /**
     * A common COSName value.
     */
@@ -709,6 +717,10 @@ public final class COSName extends COSBase implements Comparable<COSName>
      * A common COSName value.
      */
     public static final COSName H = new COSName( "H" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName GTS_PDFA1 = new COSName("GTS_PDFA1");
     /**
     * A common COSName value.
     */
@@ -903,6 +915,10 @@ public final class COSName extends COSBase implements Comparable<COSName>
      * A common COSName value.
      */
     public static final COSName MATRIX = new COSName( "Matrix" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName MAX_LEN = new COSName("MaxLen");
     /**
      * A common COSName value.
      */
@@ -1027,6 +1043,26 @@ public final class COSName extends COSBase implements Comparable<COSName>
      */
     public static final COSName OUTLINES = new COSName("Outlines");
 
+    /**
+     * A common COSName value.
+     */
+    public static final COSName OUTPUT_INTENT = new COSName("OutputIntent");
+
+    /**
+     * A common COSName value.
+     */
+    public static final COSName OUTPUT_INTENTS = new COSName("OutputIntents");
+
+    /**
+     * A common COSName value.
+     */
+    public static final COSName OUTPUT_CONDITION = new COSName("OutputCondition");
+
+    /**
+     * A common COSName value.
+     */
+    public static final COSName OUTPUT_CONDITION_IDENTIFIER = new COSName("OutputConditionIdentifier");
+
     /**
      * A common COSName value.
      */
@@ -1075,6 +1111,10 @@ public final class COSName extends COSBase implements Comparable<COSName>
     * A common COSName value.
     */
     public static final COSName PARENT = new COSName( "Parent" );
+    /**
+     * A common COSName value.
+     */
+    public static final COSName PARENT_TREE = new COSName("ParentTree");
     /**
      * A common COSName value.
      */
@@ -1168,6 +1208,12 @@ public final class COSName extends COSBase implements Comparable<COSName>
      * A common COSName value.
      */
     public static final COSName REGISTRY = new COSName( "Registry" );
+
+    /**
+     * A common COSName value.
+     */
+    public static final COSName REGISTRY_NAME = new COSName("RegistryName");
+
     /**
     * A common COSName value.
     */
@@ -1278,7 +1324,14 @@ public final class COSName extends COSBase implements Comparable<COSName>
      * A common COSName value.
      */
     public static final COSName STR_F = new COSName( "StrF" );
-
+    /**
+     * A common COSName value.
+     */
+    public static final COSName STRUCT_PARENT = new COSName("StructParent");
+    /**
+     * A common COSName value.
+     */
+    public static final COSName STRUCT_PARENTS = new COSName("StructParents");
     /**
      * A common COSName value.
      */
