@@ -22,28 +22,29 @@ import java.io.ByteArrayInputStream;
 import java.io.InputStream;
 import java.io.IOException;
 import java.io.OutputStream;
-
 import java.util.List;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.apache.pdfbox.filter.Filter;
 import org.apache.pdfbox.filter.FilterManager;
-
+import org.apache.pdfbox.io.*;
 import org.apache.pdfbox.pdfparser.PDFStreamParser;
-
 import org.apache.pdfbox.exceptions.COSVisitorException;
-
-import org.apache.pdfbox.io.RandomAccess;
-import org.apache.pdfbox.io.RandomAccessFileInputStream;
-import org.apache.pdfbox.io.RandomAccessFileOutputStream;
-
+import org.apache.pdfbox.io.IOUtils;
 /**
  * This class represents a stream object in a PDF document.
  *
  * @author <a href="mailto:ben@benlitchfield.com">Ben Litchfield</a>
- * @version $Revision: 1.41 $
+ * 
  */
 public class COSStream extends COSDictionary
 {
+    /**
+     * Log instance.
+     */
+    private static final Log LOG = LogFactory.getLog(COSStream.class);
+
     private static final int BUFFER_SIZE=16384;
 
     private RandomAccess file;
@@ -57,6 +58,16 @@ public class COSStream extends COSDictionary
      */
     private RandomAccessFileOutputStream unFilteredStream;
 
+    private RandomAccess clone (RandomAccess file) {
+        if (file == null) {
+            return null;
+        } else if (file instanceof RandomAccessFile) {
+            return file;
+        } else {
+            return ((RandomAccessBuffer)file).clone();
+        }
+    }
+
     /**
      * Constructor.  Creates a new stream with an empty dictionary.
      *
@@ -65,7 +76,7 @@ public class COSStream extends COSDictionary
     public COSStream( RandomAccess storage )
     {
         super();
-        file = storage;
+        file = clone(storage);
     }
 
     /**
@@ -77,7 +88,7 @@ public class COSStream extends COSDictionary
     public COSStream( COSDictionary dictionary, RandomAccess storage )
     {
         super( dictionary );
-        file = storage;
+        file = clone(storage);
     }
 
     /**
@@ -263,7 +274,6 @@ public class COSStream extends COSDictionary
     {
         FilterManager manager = getFilterManager();
         Filter filter = manager.getFilter( filterName );
-        InputStream input;
 
         boolean done = false;
         IOException exception = null;
@@ -277,6 +287,7 @@ public class COSStream extends COSDictionary
             //if the length is zero then don't bother trying to decode
             //some filters don't work when attempting to decode
             //with a zero length stream.  See zlib_error_01.pdf
+        	IOUtils.closeQuietly(unFilteredStream);
             unFilteredStream = new RandomAccessFileOutputStream( file );
             done = true;
         }
@@ -287,10 +298,12 @@ public class COSStream extends COSDictionary
             //try again with one less byte.
             for( int tryCount=0; !done && tryCount<5; tryCount++ )
             {
+                InputStream input = null;
                 try
                 {
                     input = new BufferedInputStream(
                         new RandomAccessFileInputStream( file, position, length ), BUFFER_SIZE );
+                	IOUtils.closeQuietly(unFilteredStream);
                     unFilteredStream = new RandomAccessFileOutputStream( file );
                     filter.decode( input, unFilteredStream, this, filterIndex );
                     done = true;
@@ -300,6 +313,10 @@ public class COSStream extends COSDictionary
                     length--;
                     exception = io;
                 }
+                finally
+                {
+                	IOUtils.closeQuietly(input);
+                }
             }
             if( !done )
             {
@@ -309,10 +326,12 @@ public class COSStream extends COSDictionary
                 length = writtenLength;
                 for( int tryCount=0; !done && tryCount<5; tryCount++ )
                 {
+                    InputStream input = null;
                     try
                     {
                         input = new BufferedInputStream(
                             new RandomAccessFileInputStream( file, position, length ), BUFFER_SIZE );
+                    	IOUtils.closeQuietly(unFilteredStream);
                         unFilteredStream = new RandomAccessFileOutputStream( file );
                         filter.decode( input, unFilteredStream, this, filterIndex );
                         done = true;
@@ -322,6 +341,10 @@ public class COSStream extends COSDictionary
                         length--;
                         exception = io;
                     }
+                    finally
+                    {
+                    	IOUtils.closeQuietly(input);
+                    }
                 }
             }
         }
@@ -373,13 +396,14 @@ public class COSStream extends COSDictionary
     {
         FilterManager manager = getFilterManager();
         Filter filter = manager.getFilter( filterName );
-        InputStream input;
 
-        input = new BufferedInputStream(
+        InputStream input = new BufferedInputStream(
             new RandomAccessFileInputStream( file, filteredStream.getPosition(),
                                                    filteredStream.getLength() ), BUFFER_SIZE );
+        IOUtils.closeQuietly(filteredStream);
         filteredStream = new RandomAccessFileOutputStream( file );
         filter.encode( input, filteredStream, this, filterIndex );
+        IOUtils.closeQuietly(input);
     }
 
     /**
@@ -407,8 +431,10 @@ public class COSStream extends COSDictionary
      */
     public OutputStream createFilteredStream() throws IOException
     {
+    	IOUtils.closeQuietly(unFilteredStream);
+    	unFilteredStream = null;
+    	IOUtils.closeQuietly(filteredStream);
         filteredStream = new RandomAccessFileOutputStream( file );
-        unFilteredStream = null;
         return new BufferedOutputStream( filteredStream, BUFFER_SIZE );
     }
 
@@ -425,9 +451,11 @@ public class COSStream extends COSDictionary
      */
     public OutputStream createFilteredStream( COSBase expectedLength ) throws IOException
     {
+      	IOUtils.closeQuietly(unFilteredStream);
+       	unFilteredStream = null;
+    	IOUtils.closeQuietly(filteredStream);
         filteredStream = new RandomAccessFileOutputStream( file );
         filteredStream.setExpectedLength( expectedLength );
-        unFilteredStream = null;
         return new BufferedOutputStream( filteredStream, BUFFER_SIZE );
     }
 
@@ -442,6 +470,7 @@ public class COSStream extends COSDictionary
     {
         setItem(COSName.FILTER, filters);
         // kill cached filtered streams
+    	IOUtils.closeQuietly(filteredStream);
         filteredStream = null;
     }
 
@@ -454,8 +483,35 @@ public class COSStream extends COSDictionary
      */
     public OutputStream createUnfilteredStream() throws IOException
     {
-        unFilteredStream = new RandomAccessFileOutputStream( file );
+        IOUtils.closeQuietly(filteredStream);
         filteredStream = null;
+    	IOUtils.closeQuietly(unFilteredStream);
+        unFilteredStream = new RandomAccessFileOutputStream( file );
         return new BufferedOutputStream( unFilteredStream, BUFFER_SIZE );
     }
+    
+    public void close()
+    {
+    	try
+    	{
+    		if (file != null)
+    		{
+    			file.close();
+    			file = null;
+    		}
+    	}
+    	catch (IOException exception)
+    	{
+    		LOG.error("Exception occured when closing the file.", exception);
+    	}
+    	if (filteredStream != null)
+    	{
+    		IOUtils.closeQuietly(filteredStream);
+    	}
+    	if (unFilteredStream != null)
+    	{
+    		IOUtils.closeQuietly(unFilteredStream);
+    	}
+    	clear();
+    }
 }
