@@ -17,6 +17,7 @@
 package org.apache.pdfbox.filter;
 
 import java.awt.image.BufferedImage;
+import java.awt.image.ColorModel;
 import java.awt.image.DataBuffer;
 import java.awt.image.DataBufferByte;
 import java.io.IOException;
@@ -28,18 +29,20 @@ import javax.imageio.ImageIO;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.pdfbox.cos.COSDictionary;
+import org.apache.pdfbox.cos.COSName;
+import org.apache.pdfbox.pdmodel.graphics.color.PDColorSpaceFactory;
 
 /**
  * This is used for the JPXDecode filter.
  *
- * @author <a href="mailto:timo.boehme@ontochem.com">Timo Böhme</a>
+ * @author <a href="mailto:timo.boehme@ontochem.com">Timo Boehme</a>
  *
  */
 public class JPXFilter implements Filter
 {
 
     /** Log instance. */
-    private static final Log log = LogFactory.getLog(JPXFilter.class);
+    private static final Log LOG = LogFactory.getLog(JPXFilter.class);
 
     /**
      * Decode JPEG2000 data using Java ImageIO library.
@@ -47,20 +50,30 @@ public class JPXFilter implements Filter
      * {@inheritDoc}
      *
      */
-    public void decode( InputStream compressedData, OutputStream result, COSDictionary options, int filterIndex )
-        throws IOException
+    public void decode(InputStream compressedData, OutputStream result, COSDictionary options, int filterIndex)
+            throws IOException
     {
-        BufferedImage bi = ImageIO.read( compressedData );
-        if ( bi != null )
+        BufferedImage bi = ImageIO.read(compressedData);
+        if (bi != null)
         {
             DataBuffer dBuf = bi.getData().getDataBuffer();
-            if ( dBuf.getDataType() == DataBuffer.TYPE_BYTE )
+            if (dBuf.getDataType() == DataBuffer.TYPE_BYTE)
             {
-                result.write( ( ( DataBufferByte ) dBuf ).getData() );
+                // maybe some wrong/missing values have to be revised/added
+                ColorModel colorModel = bi.getColorModel();
+                if (options.getItem(COSName.COLORSPACE) == null)
+                {
+                    options.setItem(COSName.COLORSPACE,
+                            PDColorSpaceFactory.createColorSpace(null, colorModel.getColorSpace()));
+                }
+                options.setInt(COSName.BITS_PER_COMPONENT, colorModel.getPixelSize() / colorModel.getNumComponents());
+                options.setInt(COSName.HEIGHT, bi.getHeight());
+                options.setInt(COSName.WIDTH, bi.getWidth());
+                result.write(((DataBufferByte) dBuf).getData());
             }
             else
             {
-                log.error( "Image data buffer not of type byte but type " + dBuf.getDataType() );
+                LOG.error("Image data buffer not of type byte but type " + dBuf.getDataType());
             }
         }
     }
@@ -68,9 +81,9 @@ public class JPXFilter implements Filter
     /**
      * {@inheritDoc}
      */
-    public void encode( InputStream rawData, OutputStream result, COSDictionary options, int filterIndex )
-        throws IOException
+    public void encode(InputStream rawData, OutputStream result, COSDictionary options, int filterIndex)
+            throws IOException
     {
-        System.err.println( "Warning: JPXFilter.encode is not implemented yet, skipping this stream." );
+        LOG.error("Warning: JPXFilter.encode is not implemented yet, skipping this stream.");
     }
 }
