@@ -38,6 +38,7 @@ import org.apache.pdfbox.cos.COSObject;
 import org.apache.pdfbox.cos.COSStream;
 import org.apache.pdfbox.cos.COSString;
 import org.apache.pdfbox.exceptions.WrappedIOException;
+import org.apache.pdfbox.io.IOUtils;
 import org.apache.pdfbox.io.PushBackInputStream;
 import org.apache.pdfbox.io.RandomAccess;
 import org.apache.pdfbox.persistence.util.COSObjectKey;
@@ -556,6 +557,10 @@ public abstract class BaseParser
                                                           PROP_PUSHBACK_SIZE, ioe );
                         }
                         // create new filtered stream
+                        if (out != null)
+                        {
+                        	IOUtils.closeQuietly(out);
+                        }
                         out = stream.createFilteredStream( streamLength );
                         // scan until we find endstream:
                         readUntilEndStream( out );
@@ -1008,7 +1013,15 @@ public abstract class BaseParser
                 do 
                 {
                     c = pdfSource.read();
-                } while ( c != '>' );
+                } while ( c != '>' && c >= 0 );
+                
+                // might have reached EOF while looking for the closing bracket
+                // this can happen for malformed PDFs only. Make sure that there is
+                // no endless loop.
+                if ( c < 0 ) 
+                {
+                    throw new IOException( "Missing closing bracket for hex string. Reached EOS." );
+                }
                 
                 // exit loop
                 break;
@@ -1639,7 +1652,7 @@ public abstract class BaseParser
         catch( NumberFormatException e )
         {
             pdfSource.unread(intBuffer.toString().getBytes("ISO-8859-1"));
-            throw new IOException( "Error: Expected an integer type, actual='" + intBuffer + "'" );
+            throw new IOException( "Error: Expected an integer type at offset "+pdfSource.getOffset());
         }
         return retval;
     }
@@ -1666,7 +1679,7 @@ public abstract class BaseParser
         catch( NumberFormatException e )
         {
             pdfSource.unread(longBuffer.toString().getBytes("ISO-8859-1"));
-            throw new IOException( "Error: Expected a long type, actual='" + longBuffer + "'" );
+            throw new IOException( "Error: Expected a long type at offset "+pdfSource.getOffset());
         }
         return retval;
     }
@@ -1697,4 +1710,16 @@ public abstract class BaseParser
         return buffer;
     }
 
+    /**
+     * Release all used resources.
+     */
+    public void clearResources()
+    {
+    	document = null;
+    	if (pdfSource != null)
+    	{
+    		IOUtils.closeQuietly(pdfSource);
+    		pdfSource = null;
+    	}
+    }
 }
