@@ -279,6 +279,26 @@ public class PDPage implements COSObjectable, Printable
         }
     }
 
+    /**
+     * This will get the key of this Page in the structural parent tree.
+     * 
+     * @return the integer key of the page's entry in the structural parent tree
+     */
+    public int getStructParents()
+    {
+        return page.getInt(COSName.STRUCT_PARENTS, 0);
+    }
+
+    /**
+     * This will set the key for this page in the structural parent tree.
+     * 
+     * @param structParents The new key for this page.
+     */
+    public void setStructParents(int structParents)
+    {
+        page.setInt(COSName.STRUCT_PARENTS, structParents);
+    }
+
     /**
      * A rectangle, expressed
      * in default user space units, defining the boundaries of the physical
@@ -709,7 +729,7 @@ public class PDPage implements COSObjectable, Printable
         //the default size is not really good resolution,
         //so create an image that is twice the size
         //and let the client scale it down.
-        return convertToImage(8, 2 * DEFAULT_USER_SPACE_UNIT_DPI);
+        return convertToImage(BufferedImage.TYPE_INT_RGB, 2 * DEFAULT_USER_SPACE_UNIT_DPI);
     }
 
     /**
@@ -779,7 +799,8 @@ public class PDPage implements COSObjectable, Printable
         graphics.scale( scaling, scaling );
         PageDrawer drawer = new PageDrawer();
         drawer.drawPage( graphics, this, pageDimension );
-
+        drawer.dispose();
+        graphics.dispose();
         return retval;
     }
 
@@ -862,6 +883,7 @@ public class PDPage implements COSObjectable, Printable
             PageDrawer drawer = new PageDrawer();
             PDRectangle cropBox = findCropBox();
             drawer.drawPage( graphics, this, cropBox.createDimension() );
+            drawer.dispose();
             return PAGE_EXISTS;
         }
         catch( IOException io )
