@@ -20,28 +20,29 @@ import java.io.IOException;
 import java.util.Hashtable;
 import java.util.Map;
 
+import org.apache.pdfbox.cos.COSArray;
 import org.apache.pdfbox.cos.COSBase;
 import org.apache.pdfbox.cos.COSDictionary;
 import org.apache.pdfbox.cos.COSName;
 import org.apache.pdfbox.pdmodel.common.COSDictionaryMap;
 import org.apache.pdfbox.pdmodel.common.PDNameTreeNode;
+import org.apache.pdfbox.pdmodel.common.PDNumberTreeNode;
 
 /**
  * A root of a structure tree.
- *
- * @author <a href="mailto:ben@benlitchfield.com">Ben Litchfield</a>,
- *  <a href="mailto:Johannes%20Koch%20%3Ckoch@apache.org%3E">Johannes Koch</a>
- * @version $Revision: 1.2 $
+ * 
+ * @author <a href="mailto:ben@benlitchfield.com">Ben Litchfield</a>, <a
+ * href="mailto:Johannes%20Koch%20%3Ckoch@apache.org%3E">Johannes Koch</a>
+ * 
  */
 public class PDStructureTreeRoot extends PDStructureNode
 {
 
-    public static final String TYPE = "StructTreeRoot";
-
+    private static final String TYPE = "StructTreeRoot";
 
     /**
      * Default Constructor.
-     *
+     * 
      */
     public PDStructureTreeRoot()
     {
@@ -50,14 +51,60 @@ public class PDStructureTreeRoot extends PDStructureNode
 
     /**
      * Constructor for an existing structure element.
-     *
+     * 
      * @param dic The existing dictionary.
      */
-    public PDStructureTreeRoot( COSDictionary dic )
+    public PDStructureTreeRoot(COSDictionary dic)
     {
         super(dic);
     }
 
+    /**
+     * Returns the K array entry.
+     * 
+     * @return the K array entry
+     */
+    public COSArray getKArray()
+    {
+        COSBase k = this.getCOSDictionary().getDictionaryObject(COSName.K);
+        if (k != null)
+        {
+            if (k instanceof COSDictionary)
+            {
+                COSDictionary kdict = (COSDictionary) k;
+                k = kdict.getDictionaryObject(COSName.K);
+                if (k instanceof COSArray)
+                {
+                    return (COSArray) k;
+                }
+            }
+            else
+            {
+                return (COSArray) k;
+            }
+        }
+        return null;
+    }
+
+    /**
+     * Returns the K entry.
+     * 
+     * @return the K entry
+     */
+    public COSBase getK()
+    {
+        return this.getCOSDictionary().getDictionaryObject(COSName.K);
+    }
+
+    /**
+     * Sets the K entry.
+     * 
+     * @param k the K value
+     */
+    public void setK(COSBase k)
+    {
+        this.getCOSDictionary().setItem(COSName.K, k);
+    }
 
     /**
      * Returns the ID tree.
@@ -66,8 +113,7 @@ public class PDStructureTreeRoot extends PDStructureNode
      */
     public PDNameTreeNode getIDTree()
     {
-        COSDictionary idTreeDic = (COSDictionary) this.getCOSDictionary()
-            .getDictionaryObject(COSName.ID_TREE);
+        COSDictionary idTreeDic = (COSDictionary) this.getCOSDictionary().getDictionaryObject(COSName.ID_TREE);
         if (idTreeDic != null)
         {
             return new PDNameTreeNode(idTreeDic, PDStructureElement.class);
@@ -85,6 +131,31 @@ public class PDStructureTreeRoot extends PDStructureNode
         this.getCOSDictionary().setItem(COSName.ID_TREE, idTree);
     }
 
+    /**
+     * Returns the parent tree.
+     * 
+     * @return the parent tree
+     */
+    public PDNumberTreeNode getParentTree()
+    {
+        COSDictionary parentTreeDic = (COSDictionary) this.getCOSDictionary().getDictionaryObject(COSName.PARENT_TREE);
+        if (parentTreeDic != null)
+        {
+            return new PDNumberTreeNode(parentTreeDic, COSBase.class);
+        }
+        return null;
+    }
+
+    /**
+     * Sets the parent tree.
+     * 
+     * @param parentTree the parent tree
+     */
+    public void setParentTree(PDNumberTreeNode parentTree)
+    {
+        this.getCOSDictionary().setItem(COSName.PARENT_TREE, parentTree);
+    }
+
     /**
      * Returns the next key in the parent tree.
      * 
@@ -95,6 +166,16 @@ public class PDStructureTreeRoot extends PDStructureNode
         return this.getCOSDictionary().getInt(COSName.PARENT_TREE_NEXT_KEY);
     }
 
+    /**
+     * Sets the next key in the parent tree.
+     * 
+     * @param parentTreeNextkey the next key in the parent tree.
+     */
+    public void setParentTreeNextKey(int parentTreeNextkey)
+    {
+        this.getCOSDictionary().setInt(COSName.PARENT_TREE_NEXT_KEY, parentTreeNextkey);
+    }
+
     /**
      * Returns the role map.
      * 
