@@ -341,12 +341,28 @@ public class PDType1Font extends PDSimpleFont
                                 StringTokenizer st = new StringTokenizer(line.replaceAll("/"," /"));
                                 // ignore the first token
                                 st.nextElement();
-                                int index = Integer.parseInt(st.nextToken());
-                                String name = st.nextToken();
-                                if(encoding == null)
-                                    log.warn("Unable to get character encoding.  Encoding defintion found without /Encoding line.");
-                                else
-                                    encoding.addCharacterEncoding(index, name.replace("/", ""));
+                                try
+                                {
+                                    int index = Integer.parseInt(st.nextToken());
+                                    String name = st.nextToken();
+                                    if(encoding == null)
+                                    {
+                                        log.warn("Unable to get character encoding. " +
+                                                "Encoding definition found without /Encoding line.");
+                                    }
+                                    else
+                                    {
+                                        encoding.addCharacterEncoding(index, name.replace("/", ""));
+                                    }
+                                }
+                                catch(NumberFormatException exception)
+                                {
+                                    // there are (tex?)-some fonts containing postscript code like the following, 
+                                    // which has to be ignored, see PDFBOX-1481
+                                    // dup dup 161 10 getinterval 0 exch putinterval ....
+                                    log.debug("Malformed encoding definition ignored (line="+line+")");
+                                }
+                                continue;
                             }
                         }
                         // according to the pdf reference, all font matrices should be same, except for type 3 fonts.
@@ -354,23 +370,60 @@ public class PDType1Font extends PDSimpleFont
                         // attached to PDFBOX-935
                         if (line.startsWith("/FontMatrix"))
                         {
-                            String matrixValues = line.substring(line.indexOf("[")+1,line.lastIndexOf("]"));
-                            StringTokenizer st = new StringTokenizer(matrixValues);
-                            COSArray array = new COSArray();
-                            if (st.countTokens() >= 6)
+                            // most likely all matrix values are in the same line than the keyword
+                            if (line.indexOf("[") > -1)
                             {
-                                try 
+                                String matrixValues = line.substring(line.indexOf("[")+1,line.lastIndexOf("]"));
+                                StringTokenizer st = new StringTokenizer(matrixValues);
+                                COSArray array = new COSArray();
+                                if (st.countTokens() >= 6)
                                 {
-                                    for (int i=0;i<6;i++)
+                                    try 
                                     {
-                                        COSFloat floatValue = new COSFloat(Float.parseFloat(st.nextToken()));
-                                        array.add(floatValue);
+                                        for (int i=0;i<6;i++)
+                                        {
+                                            COSFloat floatValue = new COSFloat(Float.parseFloat(st.nextToken()));
+                                            array.add(floatValue);
+                                        }
+                                    }
+                                    catch (NumberFormatException exception)
+                                    {
+                                        log.error("Can't read the fontmatrix from embedded font file!");
                                     }
                                     fontMatrix = new PDMatrix(array);
                                 }
-                                catch (NumberFormatException exception)
+                            }
+                            else
+                            {
+                                // there are fonts where all values are on a separate line, see PDFBOX-1611
+                                COSArray array = new COSArray();
+                                while((line = in.readLine()) != null)
                                 {
-                                    log.error("Can't read the fontmatrix from embedded font file!");
+                                    if (line.startsWith("["))
+                                    {
+                                        continue;
+                                    }
+                                    if (line.endsWith("]"))
+                                    {
+                                        break;
+                                    }
+                                    try
+                                    {
+                                        COSFloat floatValue = new COSFloat(Float.parseFloat(line));
+                                        array.add(floatValue);
+                                    }
+                                    catch (NumberFormatException exception)
+                                    {
+                                        log.error("Can't read the fontmatrix from embedded font file!");
+                                    }
+                                }
+                                if (array.size() == 6)
+                                {
+                                    fontMatrix = new PDMatrix(array);
+                                }
+                                else
+                                {
+                                    log.error("Can't read the fontmatrix from embedded font file, not enough values!");
                                 }
                             }
                         }
@@ -398,22 +451,6 @@ public class PDType1Font extends PDSimpleFont
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    @Override
-    public String encode(byte[] c, int offset, int length) throws IOException
-    {
-        if (type1CFont != null && getFontEncoding() == null)
-        {
-            return type1CFont.encode(c, offset, length);
-        }
-        else
-        {
-            return super.encode(c, offset, length);
-        }
-    }
-    
     public int encodeToCID( byte[] c, int offset, int length ) throws IOException {
       if (type1CFont != null && getFontEncoding() == null)
       {
