@@ -39,7 +39,6 @@ import org.apache.pdfbox.util.Matrix;
  * This class represents the PaintContext of an axial shading.
  * 
  * @author lehmi
- * @version $Revision: $
  * 
  */
 public class AxialShadingContext implements PaintContext 
@@ -52,6 +51,8 @@ public class AxialShadingContext implements PaintContext
 
     private float[] coords;
     private float[] domain;
+    private int[] extend0Values;
+    private int[] extend1Values;
     private boolean[] extend;
     private double x1x0; 
     private double y1y0;
@@ -205,10 +206,13 @@ public class AxialShadingContext implements PaintContext
         WritableRaster raster = getColorModel().createCompatibleWritableRaster(w, h);
         float[] input = new float[1];
         int[] data = new int[w * h * 3];
+        boolean saveExtend0 = false;
+        boolean saveExtend1 = false;
         for (int j = 0; j < h; j++) 
         {
             for (int i = 0; i < w; i++) 
             {
+                int index = (j * w + i) * 3;
                 double inputValue = x1x0 * (x + i - coords[0]); 
                 inputValue += y1y0 * (y + j - coords[1]);
                 inputValue /= denom;
@@ -218,7 +222,17 @@ public class AxialShadingContext implements PaintContext
                     // the shading has to be extended if extend[0] == true
                     if (extend[0])
                     {
-                        inputValue = domain[0];
+                        if (extend0Values == null)
+                        {
+                            inputValue = domain[0];
+                            saveExtend0 = true;
+                        }
+                        else
+                        {
+                            // use the chached values
+                            System.arraycopy(extend0Values, 0, data, index, 3);
+                            continue;
+                        }
                     }
                     else 
                     {
@@ -231,7 +245,17 @@ public class AxialShadingContext implements PaintContext
                     // the shading has to be extended if extend[1] == true
                     if (extend[1])
                     {
-                        inputValue = domain[1];
+                        if (extend1Values == null)
+                        {
+                            inputValue = domain[1];
+                            saveExtend1 = true;
+                        }
+                        else
+                        {
+                            // use the chached values
+                            System.arraycopy(extend1Values, 0, data, index, 3);
+                            continue;
+                        }
                     }
                     else 
                     {
@@ -240,7 +264,6 @@ public class AxialShadingContext implements PaintContext
                 }
                 input[0] = (float)(domain[0] + (d1d0*inputValue));
                 float[] values = null;
-                int index = (j * w + i) * 3;
                 try 
                 {
                     values = function.eval(input);
@@ -261,6 +284,18 @@ public class AxialShadingContext implements PaintContext
                 data[index] = (int)(values[0]*255);
                 data[index+1] = (int)(values[1]*255);
                 data[index+2] = (int)(values[2]*255);
+                if (saveExtend0)
+                {
+                    // chache values
+                    extend0Values = new int[3];
+                    System.arraycopy(data, index, extend0Values, 0, 3);
+                }
+                if (saveExtend1)
+                {
+                    // chache values
+                    extend1Values = new int[3];
+                    System.arraycopy(data, index, extend1Values, 0, 3);
+                }
             }
         }
         raster.setPixels(0, 0, w, h, data);
