@@ -73,8 +73,6 @@ public class PDFStreamEngine
      */
     private final Set<String> unsupportedOperators = new HashSet<String>();
     
-    private static final byte[] SPACE_BYTES = { (byte)32 };
-
     private PDGraphicsState graphicsState = null;
 
     private Matrix textMatrix = null;
@@ -354,7 +352,7 @@ public class PDFStreamEngine
         {   
             // to avoid crash as described in PDFBOX-614
             // lets see what the space displacement should be
-            spaceWidthText = (font.getFontWidth( SPACE_BYTES, 0, 1 )*glyphSpaceToTextSpaceFactor);
+            spaceWidthText = (font.getSpaceWidth()*glyphSpaceToTextSpaceFactor);
         }
         catch (Throwable exception)
         {
@@ -377,8 +375,8 @@ public class PDFStreamEngine
         textStateParameters.setValue(2,1, riseText);
 
         int pageRotation = page.findRotation();
-        float pageHeight = page.findMediaBox().getHeight();
-        float pageWidth = page.findMediaBox().getWidth();
+        float pageHeight = page.findCropBox().getHeight();
+        float pageWidth = page.findCropBox().getWidth();
 
         Matrix ctm = getGraphicsState().getCurrentTransformationMatrix();
         Matrix textXctm = new Matrix();
@@ -598,6 +596,11 @@ public class PDFStreamEngine
      */
     public Map<String,PDFont> getFonts()
     {
+        if ( streamResourcesStack.isEmpty() )
+        {
+            return Collections.emptyMap();
+        }
+        
         return streamResourcesStack.peek().getFonts();
     }
     /**
