@@ -99,6 +99,10 @@ public class TextPosition
         {
             rot += 360;
         }
+        else if (rot >= 360)
+        {
+            rot -= 360;
+        }
 
         this.maxTextHeight = maxFontH;
         this.pageHeight = page.findMediaBox().getHeight();
@@ -237,6 +241,10 @@ public class TextPosition
         {
             rot += 360;
         }
+        else if (rot >= 360)
+        {
+            rot -= 360;
+        }
 
         this.maxTextHeight = maxFontH;
         this.pageHeight = pageHeightValue;
