@@ -25,11 +25,16 @@ import org.apache.pdfbox.cos.TestCOSInteger;
 import org.apache.pdfbox.cos.TestCOSString;
 import org.apache.pdfbox.filter.TestFilters;
 import org.apache.pdfbox.io.TestIOUtils;
+import org.apache.pdfbox.io.TestRandomAccessBuffer;
 import org.apache.pdfbox.io.ccitt.TestCCITTFaxG31DDecodeInputStream;
 import org.apache.pdfbox.io.ccitt.TestPackedBitArray;
 import org.apache.pdfbox.pdmodel.TestFDF;
+import org.apache.pdfbox.pdmodel.TestPDDocument;
 import org.apache.pdfbox.pdmodel.TestPDDocumentCatalog;
 import org.apache.pdfbox.pdmodel.TestPDDocumentInformation;
+import org.apache.pdfbox.pdmodel.common.TestPDNameTreeNode;
+import org.apache.pdfbox.pdmodel.common.TestPDNumberTreeNode;
+import org.apache.pdfbox.pdmodel.edit.TestPDPageContentStream;
 import org.apache.pdfbox.pdmodel.interactive.form.TestFields;
 import org.apache.pdfbox.util.TestDateUtil;
 import org.apache.pdfbox.util.TestImageIOUtils;
@@ -81,6 +86,7 @@ public class TestAll extends TestCase
         suite.addTest( TestCOSString.suite() );
         suite.addTest( TestCOSInteger.suite() );
         suite.addTest( TestCOSFloat.suite() );
+        suite.addTestSuite( TestPDDocument.class );
         suite.addTestSuite( TestPDDocumentCatalog.class );
         suite.addTestSuite( TestPDDocumentInformation.class );
         suite.addTestSuite( org.apache.pdfbox.pdmodel.graphics.optionalcontent.TestOptionalContentGroups.class );
@@ -89,11 +95,17 @@ public class TestAll extends TestCase
         suite.addTest( org.apache.pdfbox.pdmodel.common.function.TestFunctions.suite() );
 
         suite.addTestSuite( TestIOUtils.class );
+        suite.addTestSuite( TestRandomAccessBuffer.class );
         suite.addTestSuite( TestImageIOUtils.class );
         suite.addTestSuite( TestPackedBitArray.class );
         suite.addTestSuite( TestCCITTFaxG31DDecodeInputStream.class );
 
         suite.addTestSuite( TestExtractText.class );
+        
+        suite.addTestSuite(TestPDPageContentStream.class);
+        
+        suite.addTestSuite(TestPDNameTreeNode.class);
+        suite.addTestSuite(TestPDNumberTreeNode.class);
 
         return suite;
     }
