@@ -456,11 +456,11 @@ public class CatalogValidationProcess extends AbstractProcess
         {
             // this is not a ICC_Profile
             addValidationError(ctx, new ValidationError(ERROR_GRAPHIC_OUTPUT_INTENT_ICC_PROFILE_INVALID,
-                    "DestOutputProfile isn't a ICCProfile"));
+                    "DestOutputProfile isn't a valid ICCProfile. Caused by : " + e.getMessage()));
         }
         catch (IOException e)
         {
-            throw new ValidationException("Unable to parse the ICC Profile", e);
+            throw new ValidationException("Unable to parse the ICC Profile.", e);
         }
             }
 }
